## Chapter 10. Work with PFD Definitions

This chapter provides additional information for working with PFD definitions.

You can select the following options from this display.

- · Creating PFD definition
- · Changing PFD definition
- · Copying PFD definition
- · Deleting PFD definition
- · Printing PFD definition
- · Renaming PFD definition
- · Printing database file

Select 11 (Work with PFD definitions) on the AFP utilities menu on page 139, and press the Enter key. The following display appears:

```

```